@@ -18,6 +18,7 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
+from aliyunsdkalidns.endpoint import endpoint_data
 
 class AddCustomLineRequest(RpcRequest):
 
@@ -25,30 +26,32 @@ class AddCustomLineRequest(RpcRequest):
 		RpcRequest.__init__(self, 'Alidns', '2015-01-09', 'AddCustomLine','alidns')
 		self.set_method('POST')
 
-	def get_DomainName(self):
+		if hasattr(self, "endpoint_map"):
+			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
+		if hasattr(self, "endpoint_regional"):
+			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
+
+	def get_DomainName(self): # String
 		return self.get_query_params().get('DomainName')
 
-	def set_DomainName(self,DomainName):
-		self.add_query_param('DomainName',DomainName)
-
-	def get_IpSegments(self):
+	def set_DomainName(self, DomainName):  # String
+		self.add_query_param('DomainName', DomainName)
+	def get_IpSegments(self): # RepeatList
 		return self.get_query_params().get('IpSegment')
 
-	def set_IpSegments(self, IpSegments):
-		for depth1 in range(len(IpSegments)):
-			if IpSegments[depth1].get('EndIp') is not None:
-				self.add_query_param('IpSegment.' + str(depth1 + 1) + '.EndIp', IpSegments[depth1].get('EndIp'))
-			if IpSegments[depth1].get('StartIp') is not None:
-				self.add_query_param('IpSegment.' + str(depth1 + 1) + '.StartIp', IpSegments[depth1].get('StartIp'))
-
-	def get_LineName(self):
+	def set_IpSegments(self, IpSegment):  # RepeatList
+		for depth1 in range(len(IpSegment)):
+			if IpSegment[depth1].get('EndIp') is not None:
+				self.add_query_param('IpSegment.' + str(depth1 + 1) + '.EndIp', IpSegment[depth1].get('EndIp'))
+			if IpSegment[depth1].get('StartIp') is not None:
+				self.add_query_param('IpSegment.' + str(depth1 + 1) + '.StartIp', IpSegment[depth1].get('StartIp'))
+	def get_LineName(self): # String
 		return self.get_query_params().get('LineName')
 
-	def set_LineName(self,LineName):
-		self.add_query_param('LineName',LineName)
-
-	def get_Lang(self):
+	def set_LineName(self, LineName):  # String
+		self.add_query_param('LineName', LineName)
+	def get_Lang(self): # String
 		return self.get_query_params().get('Lang')
 
-	def set_Lang(self,Lang):
-		self.add_query_param('Lang',Lang)
\ No newline at end of file
+	def set_Lang(self, Lang):  # String
+		self.add_query_param('Lang', Lang)
