@@ -18,6 +18,7 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
+from aliyunsdkalidns.endpoint import endpoint_data
 
 class AddDomainBackupRequest(RpcRequest):
 
@@ -25,20 +26,23 @@ class AddDomainBackupRequest(RpcRequest):
 		RpcRequest.__init__(self, 'Alidns', '2015-01-09', 'AddDomainBackup','alidns')
 		self.set_method('POST')
 
-	def get_DomainName(self):
+		if hasattr(self, "endpoint_map"):
+			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
+		if hasattr(self, "endpoint_regional"):
+			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
+
+	def get_DomainName(self): # String
 		return self.get_query_params().get('DomainName')
 
-	def set_DomainName(self,DomainName):
-		self.add_query_param('DomainName',DomainName)
-
-	def get_PeriodType(self):
+	def set_DomainName(self, DomainName):  # String
+		self.add_query_param('DomainName', DomainName)
+	def get_PeriodType(self): # String
 		return self.get_query_params().get('PeriodType')
 
-	def set_PeriodType(self,PeriodType):
-		self.add_query_param('PeriodType',PeriodType)
-
-	def get_Lang(self):
+	def set_PeriodType(self, PeriodType):  # String
+		self.add_query_param('PeriodType', PeriodType)
+	def get_Lang(self): # String
 		return self.get_query_params().get('Lang')
 
-	def set_Lang(self,Lang):
-		self.add_query_param('Lang',Lang)
\ No newline at end of file
+	def set_Lang(self, Lang):  # String
+		self.add_query_param('Lang', Lang)
