@@ -18,6 +18,7 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
+from aliyunsdkalidns.endpoint import endpoint_data
 
 class DescribeBatchResultCountRequest(RpcRequest):
 
@@ -25,20 +26,23 @@ class DescribeBatchResultCountRequest(RpcRequest):
 		RpcRequest.__init__(self, 'Alidns', '2015-01-09', 'DescribeBatchResultCount','alidns')
 		self.set_method('POST')
 
-	def get_BatchType(self):
+		if hasattr(self, "endpoint_map"):
+			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
+		if hasattr(self, "endpoint_regional"):
+			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
+
+	def get_BatchType(self): # String
 		return self.get_query_params().get('BatchType')
 
-	def set_BatchType(self,BatchType):
-		self.add_query_param('BatchType',BatchType)
-
-	def get_Lang(self):
+	def set_BatchType(self, BatchType):  # String
+		self.add_query_param('BatchType', BatchType)
+	def get_Lang(self): # String
 		return self.get_query_params().get('Lang')
 
-	def set_Lang(self,Lang):
-		self.add_query_param('Lang',Lang)
-
-	def get_TaskId(self):
+	def set_Lang(self, Lang):  # String
+		self.add_query_param('Lang', Lang)
+	def get_TaskId(self): # Long
 		return self.get_query_params().get('TaskId')
 
-	def set_TaskId(self,TaskId):
-		self.add_query_param('TaskId',TaskId)
\ No newline at end of file
+	def set_TaskId(self, TaskId):  # Long
+		self.add_query_param('TaskId', TaskId)
