@@ -18,6 +18,7 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
+from aliyunsdkalidns.endpoint import endpoint_data
 
 class DescribeCustomLineRequest(RpcRequest):
 
@@ -25,14 +26,18 @@ class DescribeCustomLineRequest(RpcRequest):
 		RpcRequest.__init__(self, 'Alidns', '2015-01-09', 'DescribeCustomLine','alidns')
 		self.set_method('POST')
 
-	def get_LineId(self):
+		if hasattr(self, "endpoint_map"):
+			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
+		if hasattr(self, "endpoint_regional"):
+			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
+
+	def get_LineId(self): # Long
 		return self.get_query_params().get('LineId')
 
-	def set_LineId(self,LineId):
-		self.add_query_param('LineId',LineId)
-
-	def get_Lang(self):
+	def set_LineId(self, LineId):  # Long
+		self.add_query_param('LineId', LineId)
+	def get_Lang(self): # String
 		return self.get_query_params().get('Lang')
 
-	def set_Lang(self,Lang):
-		self.add_query_param('Lang',Lang)
\ No newline at end of file
+	def set_Lang(self, Lang):  # String
+		self.add_query_param('Lang', Lang)
