@@ -18,6 +18,7 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
+from aliyunsdkalidns.endpoint import endpoint_data
 
 class DescribeDnsGtmAddrAttributeInfoRequest(RpcRequest):
 
@@ -25,20 +26,23 @@ class DescribeDnsGtmAddrAttributeInfoRequest(RpcRequest):
 		RpcRequest.__init__(self, 'Alidns', '2015-01-09', 'DescribeDnsGtmAddrAttributeInfo','alidns')
 		self.set_method('POST')
 
-	def get_Addrs(self):
+		if hasattr(self, "endpoint_map"):
+			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
+		if hasattr(self, "endpoint_regional"):
+			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
+
+	def get_Addrs(self): # String
 		return self.get_query_params().get('Addrs')
 
-	def set_Addrs(self,Addrs):
-		self.add_query_param('Addrs',Addrs)
-
-	def get_Type(self):
+	def set_Addrs(self, Addrs):  # String
+		self.add_query_param('Addrs', Addrs)
+	def get_Type(self): # String
 		return self.get_query_params().get('Type')
 
-	def set_Type(self,Type):
-		self.add_query_param('Type',Type)
-
-	def get_Lang(self):
+	def set_Type(self, Type):  # String
+		self.add_query_param('Type', Type)
+	def get_Lang(self): # String
 		return self.get_query_params().get('Lang')
 
-	def set_Lang(self,Lang):
-		self.add_query_param('Lang',Lang)
\ No newline at end of file
+	def set_Lang(self, Lang):  # String
+		self.add_query_param('Lang', Lang)
