@@ -18,6 +18,7 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
+from aliyunsdkalidns.endpoint import endpoint_data
 
 class DescribeGtmMonitorConfigRequest(RpcRequest):
 
@@ -25,14 +26,18 @@ class DescribeGtmMonitorConfigRequest(RpcRequest):
 		RpcRequest.__init__(self, 'Alidns', '2015-01-09', 'DescribeGtmMonitorConfig','alidns')
 		self.set_method('POST')
 
-	def get_MonitorConfigId(self):
+		if hasattr(self, "endpoint_map"):
+			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
+		if hasattr(self, "endpoint_regional"):
+			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
+
+	def get_MonitorConfigId(self): # String
 		return self.get_query_params().get('MonitorConfigId')
 
-	def set_MonitorConfigId(self,MonitorConfigId):
-		self.add_query_param('MonitorConfigId',MonitorConfigId)
-
-	def get_Lang(self):
+	def set_MonitorConfigId(self, MonitorConfigId):  # String
+		self.add_query_param('MonitorConfigId', MonitorConfigId)
+	def get_Lang(self): # String
 		return self.get_query_params().get('Lang')
 
-	def set_Lang(self,Lang):
-		self.add_query_param('Lang',Lang)
\ No newline at end of file
+	def set_Lang(self, Lang):  # String
+		self.add_query_param('Lang', Lang)
