@@ -18,6 +18,7 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
+from aliyunsdkalidns.endpoint import endpoint_data
 
 class DescribeRecordStatisticsRequest(RpcRequest):
 
@@ -25,38 +26,38 @@ class DescribeRecordStatisticsRequest(RpcRequest):
 		RpcRequest.__init__(self, 'Alidns', '2015-01-09', 'DescribeRecordStatistics','alidns')
 		self.set_method('POST')
 
-	def get_Rr(self):
+		if hasattr(self, "endpoint_map"):
+			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
+		if hasattr(self, "endpoint_regional"):
+			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
+
+	def get_Rr(self): # String
 		return self.get_query_params().get('Rr')
 
-	def set_Rr(self,Rr):
-		self.add_query_param('Rr',Rr)
-
-	def get_DomainName(self):
+	def set_Rr(self, Rr):  # String
+		self.add_query_param('Rr', Rr)
+	def get_DomainName(self): # String
 		return self.get_query_params().get('DomainName')
 
-	def set_DomainName(self,DomainName):
-		self.add_query_param('DomainName',DomainName)
-
-	def get_StartDate(self):
+	def set_DomainName(self, DomainName):  # String
+		self.add_query_param('DomainName', DomainName)
+	def get_StartDate(self): # String
 		return self.get_query_params().get('StartDate')
 
-	def set_StartDate(self,StartDate):
-		self.add_query_param('StartDate',StartDate)
-
-	def get_EndDate(self):
+	def set_StartDate(self, StartDate):  # String
+		self.add_query_param('StartDate', StartDate)
+	def get_EndDate(self): # String
 		return self.get_query_params().get('EndDate')
 
-	def set_EndDate(self,EndDate):
-		self.add_query_param('EndDate',EndDate)
-
-	def get_DomainType(self):
+	def set_EndDate(self, EndDate):  # String
+		self.add_query_param('EndDate', EndDate)
+	def get_DomainType(self): # String
 		return self.get_query_params().get('DomainType')
 
-	def set_DomainType(self,DomainType):
-		self.add_query_param('DomainType',DomainType)
-
-	def get_Lang(self):
+	def set_DomainType(self, DomainType):  # String
+		self.add_query_param('DomainType', DomainType)
+	def get_Lang(self): # String
 		return self.get_query_params().get('Lang')
 
-	def set_Lang(self,Lang):
-		self.add_query_param('Lang',Lang)
\ No newline at end of file
+	def set_Lang(self, Lang):  # String
+		self.add_query_param('Lang', Lang)
