@@ -18,6 +18,7 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
+from aliyunsdkalidns.endpoint import endpoint_data
 
 class SetGtmAccessModeRequest(RpcRequest):
 
@@ -25,20 +26,23 @@ class SetGtmAccessModeRequest(RpcRequest):
 		RpcRequest.__init__(self, 'Alidns', '2015-01-09', 'SetGtmAccessMode','alidns')
 		self.set_method('POST')
 
-	def get_StrategyId(self):
+		if hasattr(self, "endpoint_map"):
+			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
+		if hasattr(self, "endpoint_regional"):
+			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
+
+	def get_StrategyId(self): # String
 		return self.get_query_params().get('StrategyId')
 
-	def set_StrategyId(self,StrategyId):
-		self.add_query_param('StrategyId',StrategyId)
-
-	def get_Lang(self):
+	def set_StrategyId(self, StrategyId):  # String
+		self.add_query_param('StrategyId', StrategyId)
+	def get_Lang(self): # String
 		return self.get_query_params().get('Lang')
 
-	def set_Lang(self,Lang):
-		self.add_query_param('Lang',Lang)
-
-	def get_AccessMode(self):
+	def set_Lang(self, Lang):  # String
+		self.add_query_param('Lang', Lang)
+	def get_AccessMode(self): # String
 		return self.get_query_params().get('AccessMode')
 
-	def set_AccessMode(self,AccessMode):
-		self.add_query_param('AccessMode',AccessMode)
\ No newline at end of file
+	def set_AccessMode(self, AccessMode):  # String
+		self.add_query_param('AccessMode', AccessMode)
