@@ -18,6 +18,7 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
+from aliyunsdkalidns.endpoint import endpoint_data
 
 class UpdateGtmRecoveryPlanRequest(RpcRequest):
 
@@ -25,32 +26,33 @@ class UpdateGtmRecoveryPlanRequest(RpcRequest):
 		RpcRequest.__init__(self, 'Alidns', '2015-01-09', 'UpdateGtmRecoveryPlan','alidns')
 		self.set_method('POST')
 
-	def get_FaultAddrPool(self):
+		if hasattr(self, "endpoint_map"):
+			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
+		if hasattr(self, "endpoint_regional"):
+			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
+
+	def get_FaultAddrPool(self): # String
 		return self.get_query_params().get('FaultAddrPool')
 
-	def set_FaultAddrPool(self,FaultAddrPool):
-		self.add_query_param('FaultAddrPool',FaultAddrPool)
-
-	def get_Remark(self):
+	def set_FaultAddrPool(self, FaultAddrPool):  # String
+		self.add_query_param('FaultAddrPool', FaultAddrPool)
+	def get_Remark(self): # String
 		return self.get_query_params().get('Remark')
 
-	def set_Remark(self,Remark):
-		self.add_query_param('Remark',Remark)
-
-	def get_Name(self):
+	def set_Remark(self, Remark):  # String
+		self.add_query_param('Remark', Remark)
+	def get_Name(self): # String
 		return self.get_query_params().get('Name')
 
-	def set_Name(self,Name):
-		self.add_query_param('Name',Name)
-
-	def get_RecoveryPlanId(self):
+	def set_Name(self, Name):  # String
+		self.add_query_param('Name', Name)
+	def get_RecoveryPlanId(self): # Long
 		return self.get_query_params().get('RecoveryPlanId')
 
-	def set_RecoveryPlanId(self,RecoveryPlanId):
-		self.add_query_param('RecoveryPlanId',RecoveryPlanId)
-
-	def get_Lang(self):
+	def set_RecoveryPlanId(self, RecoveryPlanId):  # Long
+		self.add_query_param('RecoveryPlanId', RecoveryPlanId)
+	def get_Lang(self): # String
 		return self.get_query_params().get('Lang')
 
-	def set_Lang(self,Lang):
-		self.add_query_param('Lang',Lang)
\ No newline at end of file
+	def set_Lang(self, Lang):  # String
+		self.add_query_param('Lang', Lang)
